#include <qlabel.h>
#include <qgroupbox.h>
#include <qwidget.h>
#include <qcheckbox.h>
#include <qspinbox.h>
#include <qhbox.h>

#include <kconfig.h>
#include <klocale.h>

#include "feedbackconfigpage.h"

FeedbackConfigPage::FeedbackConfigPage(QWidget *parent, const char *name)
  : QVBox(parent, name), _systemBeep(NULL), _displayRecognized(NULL),
    _posX(NULL), _posY(NULL), _lifeLength(NULL),
    _readingOptions(false)
  {
  QGroupBox *gBox = new QGroupBox(1, Qt::Horizontal, i18n("Audible"),
				  this, "audibleBox");

  _systemBeep = new QCheckBox(i18n("Play System Bell"),
			      gBox, "systemBell");
  connect(_systemBeep, SIGNAL(toggled(bool)),
	  this, SLOT(slotToggled(bool)));
  
  gBox = new QGroupBox(1, Qt::Horizontal, i18n("Recognized Dialog"),
		       this, "gBox");

  _displayRecognized = new QCheckBox(i18n("Display recognized dialog"),
				     gBox, "displayRecognized");
  connect(_displayRecognized, SIGNAL(toggled(bool)),
	  this, SLOT(slotToggled(bool)));
  
  QHBox *hBox = new QHBox(gBox);
  (void) new QLabel(i18n("X Position:"), hBox);
  _posX = new QSpinBox(0, 5000, 2, hBox, "posX");
  connect(_posX, SIGNAL(valueChanged(int)),
	  this, SLOT(slotValueChanged(int)));
  
  hBox = new QHBox(gBox);
  (void) new QLabel(i18n("Y Position:"), hBox);
  _posY = new QSpinBox(0, 5000, 2, hBox, "posY");
  connect(_posY, SIGNAL(valueChanged(int)),
	  this, SLOT(slotValueChanged(int)));
  
  hBox = new QHBox(gBox);
  (void) new QLabel(i18n("Time Visible:"), hBox);
  _lifeLength = new QSpinBox(0, 1000, 1, hBox, "lifeLength");
  _lifeLength->setSuffix(i18n("  seconds"));
  connect(_lifeLength, SIGNAL(valueChanged(int)),
	  this, SLOT(slotValueChanged(int)));
  
  QWidget *spacer = new QWidget(this, "spacer");
  setStretchFactor(spacer, 1);
  }

FeedbackConfigPage::~FeedbackConfigPage()
  {
  }

void FeedbackConfigPage::readOptions(KConfig &config)
  {
  _readingOptions = true;
  
  config.setGroup("Feedback");
  _systemBeep->setChecked(config.readBoolEntry("System Beep", false));
  _displayRecognized->setChecked(config.readBoolEntry("Display Recognized",
						      true));
  _posX->setValue(config.readNumEntry("X Pos", 10));
  _posY->setValue(config.readNumEntry("Y Pos", 10));
  _lifeLength->setValue(config.readNumEntry("Life Length", 3));

  _readingOptions = false;
  }

void FeedbackConfigPage::writeOptions(KConfig &config)
  {
  config.setGroup("Feedback");
  config.writeEntry("System Beep", _systemBeep->isChecked());
  config.writeEntry("Display Recognized", _displayRecognized->isChecked());
  config.writeEntry("X Pos", _posX->value());
  config.writeEntry("Y Pos", _posY->value());
  config.writeEntry("Life Length", _lifeLength->value());
  }

////////////////////////////////
// SLOTS
void FeedbackConfigPage::slotToggled(bool)
  {
  if (!_readingOptions)
    emit modified();
  }

void FeedbackConfigPage::slotValueChanged(int)
  {
  if (!_readingOptions)
    emit modified();
  }
