#include <qlistview.h>
#include <qpushbutton.h>

#include <kconfig.h>
#include <kbuttonbox.h>
#include <klocale.h>

#include "gestureconfigpage.h"
#include "gesture.h"
#include "newgesturewizard.h"
#include "modifydialog.h"

GestureConfigPage::GestureConfigPage(QWidget *parent, const char *name)
  : QHBox(parent, name), _newButton(NULL), _removeButton(NULL),
    _modifyButton(NULL), _gestureListView(NULL), _gestureList()
  {
  _gestureListView = new QListView(this, "gestureListView");
  _gestureListView->addColumn(i18n("Gesture Name"));
  setStretchFactor(_gestureListView, 1);
  connect(_gestureListView, SIGNAL(currentChanged(QListViewItem*)),
	  this, SLOT(slotCurrentChanged(QListViewItem*)));

  KButtonBox *box = new KButtonBox(this, Qt::Vertical);
 
  _newButton = box->addButton(i18n("&New"), this,
			      SLOT(slotNewButtonClicked()));
  _removeButton = box->addButton(i18n("&Remove"), this,
				 SLOT(slotRemoveButtonClicked()));
  _modifyButton = box->addButton(i18n("&Modify"), this,
				 SLOT(slotModifyButtonClicked()));

  slotCurrentChanged(NULL);

  _gestureList.clear();
  }

GestureConfigPage::~GestureConfigPage()
  {
  _gestureList.clear();
  }

void GestureConfigPage::readOptions(KConfig &config)
  {
  _gestureList.clear();

  _gestureList = Gesture::readGestures(config);

  // Populate the listview
  _gestureListView->clear();

  QListIterator<Gesture> iter(_gestureList);
  for (iter.toFirst(); iter.current(); ++iter)
    {
    (void) new QListViewItem(_gestureListView,
			     iter.current()->getName(),
			     QString::number(iter.current()->getUID()));
    }
  }

void GestureConfigPage::writeOptions(KConfig &config)
  {
  Gesture::writeGestures(_gestureList, config);
  }

/////////////////////////////////////
// SLOTS

void GestureConfigPage::slotNewButtonClicked()
  {
  NewGestureWizard wizard(_gestureList, this, "newGestureWizard");

  if (wizard.exec())
    {
    Gesture *gest = wizard.getGesture();

    _gestureList.append(gest);
    (void) new QListViewItem(_gestureListView,
			     gest->getName(),
			     QString::number(gest->getUID()));

    emit modified();
    }
  }

void GestureConfigPage::slotRemoveButtonClicked()
  {
  QListViewItem *item = _gestureListView->selectedItem();

  if (item)
    {
    Q_UINT32 uid = item->text(1).toUInt();

    delete item;
    
    Gesture *gest = findGesture(uid);
    _gestureList.removeRef(gest);
    }
  }

void GestureConfigPage::slotModifyButtonClicked()
  {
   QListViewItem *item = _gestureListView->selectedItem();

  if (item)
    {
    Q_UINT32 uid = item->text(1).toUInt();

    Gesture *gest = findGesture(uid);

    ASSERT(gest);
    
    ModifyDialog dialog(*gest,
			this, "modifyDialog");

    if (dialog.exec())
      {
      gest->setName(dialog.getGestureName());
      gest->setAction(dialog.getAction());
      item->setText(0, gest->getName());
      }
    }
  }

void GestureConfigPage::slotCurrentChanged(QListViewItem *item)
  {
  _removeButton->setEnabled(item != NULL);
  _modifyButton->setEnabled(item != NULL);
  }

Gesture *GestureConfigPage::findGesture(Q_UINT32 uid)
  {
  QListIterator<Gesture> iter(_gestureList);
  bool found = false;
  Gesture *gest = NULL;
  
  for (iter.toFirst(); iter.current() && !found; ++iter)
    {
    if (iter.current()->getUID() == uid)
      {
      found = true;
      gest = iter.current();
      }
    }

  return gest;
  }
