#include <qlabel.h>
#include <qlayout.h>

#include <kconfig.h>

#include "recognizeddialog.h"
#include "gesturedrawer.h"
#include "gesture.h"

RecognizedDialog::RecognizedDialog(QWidget *parent, const char *name)
  : QDialog(parent, name, false,
	    Qt::WStyle_Customize | Qt::WStyle_NoBorder |
	    Qt::WStyle_StaysOnTop),
    _drawer(NULL), _gestureName(NULL), _hideTimer(this, "hideTimer"),
    _xPos(10), _yPos(10), _lifeLength(3)
  {
  connect(&_hideTimer, SIGNAL(timeout()), this, SLOT(slotHideTimeout()));

  setBackgroundColor(white);
  
  QHBoxLayout *layout = new QHBoxLayout(this);
  layout->setMargin(5);
  layout->setSpacing(5);

  _drawer = new GestureDrawer(this, "drawer");
  layout->addWidget(_drawer);

  _gestureName = new QLabel(this, "gestureName");
  _gestureName->setBackgroundColor(white);
  layout->addWidget(_gestureName);
  }

RecognizedDialog::~RecognizedDialog()
  {
  }

void RecognizedDialog::show(Gesture &gest)
  {
  _drawer->setData(gest.getData());
  _gestureName->setText(gest.getName());
  
  resize(layout()->sizeHint());

  // Display in the proper location of the screen
  move(_xPos, _yPos);

  QDialog::raise();
  QDialog::show();
  
  _hideTimer.start(_lifeLength * 1000, true);
  }

void RecognizedDialog::slotHideTimeout()
  {
  hide();
  }

void RecognizedDialog::readOptions(KConfig &config)
  {
  config.setGroup("Feedback");
  _xPos = config.readNumEntry("X Pos", 10);
  _yPos = config.readNumEntry("Y Pos", 10);
  _lifeLength = config.readNumEntry("Life Length", 3);
  }

void RecognizedDialog::writeOptions(KConfig &)
  {
  // no-op
  }
